# SHiB onlien tutorial survey

Note : You may leave any answer blank you do not wish to answer
Please answer the following questions to the best of your ability

Question | Strongly disagree | Disagree | Neither agree nor disagree | Agree | Strongly Agree
--- | --- | --- | --- | --- | ---
I think that I would like to use this tutorial to learn how to place sensors | 1 | 2 | 3 | 4 | 5
I found the tutorial unecessarily complex | 1 | 2 | 3 | 4 | 5
I thought the tutorial was easy to use | 1 | 2 | 3 | 4 | 5
I think that I would need assistance to be able to use this tutorial | 1 | 2 | 3 | 4 | 5
I thought there was too much inconsistency in this tutorial | 1 | 2 | 3 | 4 | 5
I found the tutorial very cumbersome to use | 1 | 2 | 3 | 4 | 5
I found the various functions in this tutorial were well integrated | 1 | 2 | 3 | 4 | 5
I would imagine that most people would learn to use this tutorial very quickly | 1 | 2 | 3 | 4 | 5
I felet very confident using this tutorial | 1 | 2 | 3 | 4 | 5
I needed to learn a lot of things before I could get going with this tutorial | 1 | 2 | 3 | 4 | 5
I think this tutorial is very helpful | 1 | 2 | 3 | 4 | 5